==> danya-0.3.4-py3-none-any.whl: danya/search.py <==
import requests
import sys
import textwrap
import time
import importlib.resources

def read_txt_file(file_name):
    with importlib.resources.open_text('danya.data', file_name) as file:
        content = file.read()
    return content

class Client:
    def __init__(self, model='gpt-4o'):
        self.url = 'http://5.35.46.26:10500/chat'
        self.model = 'gpt-4o'
        self.model_selected = False
        self.system_prompt = ('В тексте ниже найди ответ по теме, которую я скажу.'
                              'Выпиши только нужную часть из текста, ничего не пиши от себя, не меняй!'
                              + read_txt_file('theory_c.txt'))

    def get_response(self, message):
        headers = {
            'Content-Type': 'application/json'
        }

        messages = [
            {'role': 'system', 'content': self.system_prompt},
            {'role': 'user', 'content': message}
        ]

        data = {
            'model': self.model,
            'messages': messages
        }

        response = requests.post(self.url, headers=headers, json=data)
        
        return response.json()['choices'][0]['message']['content']


class ClientManager:
    _client_instance = None

    @classmethod
    def get_client(cls, skip_selection=False):
        if cls._client_instance is None:
            cls._client_instance = Client()
            if not skip_selection:
                cls._client_instance.select_model()
        return cls._client_instance


def search(topic):
    """
    Отправляет запрос к модели для поиска в теории по заданной теме.

    Параметры:
        topic (str): Тема или запрос, который нужно отправить модели для анализа.

    Возвращает:
        str: Ответ модели, содержащий извлечённую информацию по заданной теме.
    """
    client = ClientManager.get_client(skip_selection=True)

    return client.get_response(topic)

==> danya-0.4.1-py3-none-any.whl: danya/search.py <==
import requests
import sys
import textwrap
import time
import importlib.resources

def read_txt_file(file_name):
    with importlib.resources.open_text('danya.data', file_name) as file:
        content = file.read()
    return content

class Client:
    def __init__(self, model='gpt-4o'):
        self.url = 'http://5.35.46.26:10500/chat'
        self.model = 'gpt-4o'
        self.model_selected = False
        self.system_prompt = ('В тексте ниже найди ответ по теме, которую я скажу.'
                              'Выпиши только нужный пункт из текста (1-29) целиком, ничего не пиши от себя, не меняй и не сокращай!'
                              + read_txt_file('theory_c.txt'))

    def get_response(self, message):
        headers = {
            'Content-Type': 'application/json'
        }

        messages = [
            {'role': 'system', 'content': self.system_prompt},
            {'role': 'user', 'content': message}
        ]

        data = {
            'model': self.model,
            'messages': messages
        }

        response = requests.post(self.url, headers=headers, json=data)
        
        return response.json()['choices'][0]['message']['content']


class ClientManager:
    _client_instance = None

    @classmethod
    def get_client(cls, skip_selection=False):
        if cls._client_instance is None:
            cls._client_instance = Client()
            if not skip_selection:
                cls._client_instance.select_model()
        return cls._client_instance


def search(topic):
    """
    Отправляет запрос к модели для поиска в теории по заданной теме.

    Параметры:
        topic (str): Тема или запрос, который нужно отправить модели для анализа.

    Возвращает:
        str: Ответ модели, содержащий извлечённую информацию по заданной теме.
    """
    client = ClientManager.get_client(skip_selection=True)

    return client.get_response(topic)
